@@ -334,6 +334,9 @@ def mv(source_path, destination_path, project_id=None, object_client=None):
     project_id = project_id or get_context().project_id
     object_client = object_client or ObjectClient(get_session())
 
+    if source_path == destination_path:
+        return
+
     cp(
         source_path,
         destination_path,
@@ -500,7 +503,7 @@ def open(project_path, mode="r", temp_dir=None, project_id=None, **kwargs):
         standard python open function. Writing is currently not supported.
     temp_dir : str
         A directory on the local filesystem where you would like the file to be
-        saved into temporarily. Note that on SherlockML servers, the default
+        saved into temporarily. Note that on Faculty servers, the default
         temporary directory can break with large files, so if your file is
         upwards of 2GB, it is recommended to specify temp_dir='/project'.
     project_id : str, optional
